==> ant-design-vue-4.0.3.jar: META-INF/resources/webjars/ant-design-vue/4.0.3/lib/vc-slider/src/Handle.d.ts <==
import type { PropType } from 'vue';
declare const _default: import("vue").DefineComponent<{
    prefixCls: StringConstructor;
    vertical: {
        type: BooleanConstructor;
        default: any;
    };
    offset: NumberConstructor;
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    min: NumberConstructor;
    max: NumberConstructor;
    value: NumberConstructor;
    tabindex: import("vue-types").VueTypeDef<string | number>;
    reverse: {
        type: BooleanConstructor;
        default: any;
    };
    ariaLabel: StringConstructor;
    ariaLabelledBy: StringConstructor;
    ariaValueTextFormatter: FunctionConstructor;
    onMouseenter: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMouseleave: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMousedown: {
        type: PropType<(payload: MouseEvent) => void>;
    };
}, () => import("vue/jsx-runtime").JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    prefixCls: StringConstructor;
    vertical: {
        type: BooleanConstructor;
        default: any;
    };
    offset: NumberConstructor;
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    min: NumberConstructor;
    max: NumberConstructor;
    value: NumberConstructor;
    tabindex: import("vue-types").VueTypeDef<string | number>;
    reverse: {
        type: BooleanConstructor;
        default: any;
    };
    ariaLabel: StringConstructor;
    ariaLabelledBy: StringConstructor;
    ariaValueTextFormatter: FunctionConstructor;
    onMouseenter: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMouseleave: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMousedown: {
        type: PropType<(payload: MouseEvent) => void>;
    };
}>>, {
    vertical: boolean;
    reverse: boolean;
    disabled: boolean;
}, {}>;
export default _default;

==> ant-design-vue-4.1.1.jar: META-INF/resources/webjars/ant-design-vue/4.1.1/lib/vc-slider/src/Handle.d.ts <==
import type { PropType } from 'vue';
declare const _default: import("vue").DefineComponent<{
    prefixCls: StringConstructor;
    vertical: {
        type: BooleanConstructor;
        default: any;
    };
    offset: NumberConstructor;
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    min: NumberConstructor;
    max: NumberConstructor;
    value: NumberConstructor;
    tabindex: import("vue-types").VueTypeDef<string | number>;
    reverse: {
        type: BooleanConstructor;
        default: any;
    };
    ariaLabel: StringConstructor;
    ariaLabelledBy: StringConstructor;
    ariaValueTextFormatter: FunctionConstructor;
    onMouseenter: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMouseleave: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMousedown: {
        type: PropType<(payload: MouseEvent) => void>;
    };
}, () => import("vue/jsx-runtime").JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    prefixCls: StringConstructor;
    vertical: {
        type: BooleanConstructor;
        default: any;
    };
    offset: NumberConstructor;
    disabled: {
        type: BooleanConstructor;
        default: any;
    };
    min: NumberConstructor;
    max: NumberConstructor;
    value: NumberConstructor;
    tabindex: import("vue-types").VueTypeDef<string | number>;
    reverse: {
        type: BooleanConstructor;
        default: any;
    };
    ariaLabel: StringConstructor;
    ariaLabelledBy: StringConstructor;
    ariaValueTextFormatter: FunctionConstructor;
    onMouseenter: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMouseleave: {
        type: PropType<(payload: MouseEvent) => void>;
    };
    onMousedown: {
        type: PropType<(payload: MouseEvent) => void>;
    };
}>>, {
    vertical: boolean;
    reverse: boolean;
    disabled: boolean;
}, {}>;
export default _default;
